@@ -315,7 +315,27 @@ on noteShow(accountName, noteID)
 	end tell
 end noteShow
 
-(*********** Folder Class *********)
+on noteAddAttachment(accountName, noteID, attachmentPath)
+	tell application "Notes"
+		tell account accountName
+			set theNote to note id (noteID)
+			set theAttachment to make new attachment at theNote with data POSIX file attachmentPath
+			return id of theAttachment
+		end tell
+	end tell
+end noteAddAttachment
+
+(******** Folder Class *********)
+
+on noteGetAttachments(accountName, noteID)
+	(* Get attachments for noteID in accountName *)
+	tell application "Notes"
+		tell account accountName
+			set attachmentIDs to id of attachments of note id (noteID)
+			return attachmentIDs
+		end tell
+	end tell
+end noteGetAttachments
 
 on folderGetName(accountName, folderID)
 	(* Get name of folder*)
@@ -492,6 +512,38 @@ on accountID(accountName)
 	end tell
 end accountID
 
+(********** Attachment Class **********)
+
+on attachmentSaveAttachment(accountName, noteID, attachmentID, thePath)
+	(* save a note attachment *)
+	tell application "Notes"
+		tell account accountName
+			repeat with theAttachment in attachments of note id (noteID)
+				set theID to «class seld» of (theAttachment as record)
+				if theID = attachmentID then
+					tell theAttachment
+						save in POSIX file thePath
+					end tell
+				end if
+			end repeat
+		end tell
+	end tell
+end attachmentSaveAttachment
+
+on attachmentGetName(accountName, noteID, attachmentID)
+	(* Return attachment name *)
+	tell application "Notes"
+		tell account accountName
+			repeat with theAttachment in attachments of note id (noteID)
+				set theID to «class seld» of (theAttachment as record)
+				if theID = attachmentID then
+					return name of theAttachment
+				end if
+			end repeat
+		end tell
+	end tell
+end attachmentGetName
+
 (********** Test **********)
 
 """
\ No newline at end of file
